==> aspose_words_cloud-19.8.0-py2-none-any.whl: asposewordscloud/models/requests/execute_mail_merge_online_request.py <==
# --------------------------------------------------------------------------------
# <copyright company="Aspose" file="ExecuteMailMergeOnlineRequest.py">
#   Copyright (c) 2019 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------


class ExecuteMailMergeOnlineRequest(object):
    """
    Request model for execute_mail_merge_online operation.
    Initializes a new instance.
    :param template File with template
    :param data File with mailmerge data
    :param with_regions With regions flag.
    :param cleanup Clean up options.
    :param document_file_name This file name will be used when resulting document has dynamic field for document file name {filename}. If it is not setted, \"template\" will be used instead. 
    """

    def __init__(self, template, data, with_regions=None, cleanup=None, document_file_name=None):
        self.template = template
        self.data = data
        self.with_regions = with_regions
        self.cleanup = cleanup
        self.document_file_name = document_file_name

==> aspose_words_cloud-20.5.0-py2-none-any.whl: asposewordscloud/models/requests/execute_mail_merge_online_request.py <==
# --------------------------------------------------------------------------------
# <copyright company="Aspose" file="ExecuteMailMergeOnlineRequest.py">
#   Copyright (c) 2019 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# --------------------------------------------------------------------------------


class ExecuteMailMergeOnlineRequest(object):
    """
    Request model for execute_mail_merge_online operation.
    Initializes a new instance.
    :param template File with template
    :param data File with mailmerge data
    :param with_regions With regions flag.
    :param cleanup Clean up options.
    :param document_file_name This file name will be used when resulting document has dynamic field for document file name {filename}. If it is not set, "template" will be used instead.
    """

    def __init__(self, template, data, with_regions=None, cleanup=None, document_file_name=None):
        self.template = template
        self.data = data
        self.with_regions = with_regions
        self.cleanup = cleanup
        self.document_file_name = document_file_name
